API
===

.. automodule:: mx_bluesky

    ``mx_bluesky``
    -----------------------------------

This is the internal API reference for mx-bluesky

.. data:: mx_bluesky.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm
